Shared toolbars - CKEditor Sample

# CKEditor Sample

Editor 1 (uses the shared toolbar and element path):
<p>This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.</p>

Editor 2 (uses the shared toolbar and element path):
<p>This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.</p>

Editor 3 (uses the shared toolbar only):
<p>This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.</p>

Editor 4 (no shared spaces):
<p>This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.</p>